@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,6 +24,7 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QListWidget>
@@ -31,8 +32,12 @@
 #include <QPointer>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <kwidgetsaddons_version.h>
+#include <QWindow>
 
+namespace
+{
+static const char myNotesAgentAlarmDialogName[] = "NotesAgentAlarmDialog";
+}
 NotesAgentAlarmDialog::NotesAgentAlarmDialog(QWidget *parent)
     : QDialog(parent)
 {
@@ -103,18 +108,18 @@ void NotesAgentAlarmDialog::slotCustomContextMenuRequested(const QPoint &pos)
 
 void NotesAgentAlarmDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openStateConfig(), "NotesAgentAlarmDialog");
-    const QSize size = grp.readEntry("Size", QSize(300, 200));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(300, 200));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myNotesAgentAlarmDialogName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void NotesAgentAlarmDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openStateConfig(), "NotesAgentAlarmDialog");
-    grp.writeEntry("Size", size());
-    grp.sync();
+    KConfigGroup group(KSharedConfig::openStateConfig(), myNotesAgentAlarmDialogName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void NotesAgentAlarmDialog::addListAlarm(const Akonadi::Item::List &lstAlarm)
@@ -143,20 +148,12 @@ void NotesAgentAlarmDialog::slotShowNote()
 
 void NotesAgentAlarmDialog::slotRemoveAlarm()
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int answer = KMessageBox::warningTwoActions(this,
-#else
-    const int answer = KMessageBox::warningYesNo(this,
-#endif
                                                       i18n("Are you sure to remove alarm?"),
                                                       i18nc("@title:window", "Remove Alarm"),
                                                       KStandardGuiItem::remove(),
                                                       KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-    if (answer == KMessageBox::Yes) {
-#endif
         const Akonadi::Item::Id id = mListWidget->currentItemId();
         if (id != -1) {
             Akonadi::Item item(id);
