@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #pragma once
 
 #include <KPIMTextEdit/RichTextEditor>
-namespace PimCommonAutoCorrection
+namespace TextAutoCorrection
 {
 class AutoCorrection;
 }
@@ -25,9 +25,8 @@ public:
     explicit RichTextEditWithAutoCorrection(QWidget *parent = nullptr);
     ~RichTextEditWithAutoCorrection() override;
 
-    Q_REQUIRED_RESULT PimCommonAutoCorrection::AutoCorrection *autocorrection() const;
-
-    void setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect);
+    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
 
     void setAutocorrectionLanguage(const QString &language);
 
