@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
    SPDX-FileCopyrightText: 2021 Alexander Lohnau <alexander.lohnau@gmx.de>
 
    SPDX-License-Identifier: GPL-2.0-or-later
@@ -19,8 +19,13 @@
 #include "configdialog/knoteeditorconfigwidget.h"
 #include <KAuthorized>
 #include <KLocalizedString>
-#include <KNS3/QtQuickDialogWrapper>
 
+#include <knewstuff_version.h>
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
+#include <KNS3/QtQuickDialogWrapper>
+#else
+#include <KNSWidgets/QtQuickDialogWrapper>
+#endif
 #include <QCheckBox>
 #include <QLabel>
 #include <QLineEdit>
@@ -151,7 +156,7 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent, const QVariantList &args)
     layout->addWidget(label_PrintAction, 0, 0);
 
     mSelectTheme = new KNotePrintSelectThemeComboBox(this);
-    connect(mSelectTheme, qOverload<int>(&QComboBox::activated), this, &KNotePrintConfig::slotThemeChanged);
+    connect(mSelectTheme, &QComboBox::activated, this, &KNotePrintConfig::slotThemeChanged);
     label_PrintAction->setBuddy(mSelectTheme);
     layout->addWidget(mSelectTheme, 0, 1);
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
@@ -167,8 +172,13 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent, const QVariantList &args)
 
 void KNotePrintConfig::slotDownloadNewThemes()
 {
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto newStuffDialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("kwinswitcher.knsrc"));
     connect(newStuffDialog, &KNS3::QtQuickDialogWrapper::closed, this, [newStuffDialog, this]() {
+#else
+    auto newStuffDialog = new KNSWidgets::QtQuickDialogWrapper(QStringLiteral("kwinswitcher.knsrc"));
+    connect(newStuffDialog, &KNSWidgets::QtQuickDialogWrapper::closed, this, [newStuffDialog, this]() {
+#endif
         if (!newStuffDialog->changedEntries().isEmpty()) {
             mSelectTheme->loadThemes();
         }
