@@ -52,9 +52,11 @@
 #include <QSizeGrip>
 #include <QTextEdit>
 #include <QVBoxLayout>
+#include <QWindow>
 
 #if KDEPIM_HAVE_X11
 #include <KWindowSystem/NETWM>
+#include <KX11Extras>
 #include <fixx11h.h>
 #endif
 
@@ -159,7 +161,7 @@ void KNote::saveNote(bool force, bool sync)
     }
 #if KDEPIM_HAVE_X11
     KWindowInfo info(winId(), NET::WMDesktop);
-    const int count = KWindowSystem::numberOfDesktops();
+    const int count = KX11Extras::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
         if (info.isOnDesktop(n)) {
             if (attribute->desktop() != n) {
@@ -320,7 +322,7 @@ void KNote::updateAllAttributes()
     auto attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
 #if KDEPIM_HAVE_X11
     KWindowInfo info(winId(), NET::WMDesktop);
-    const int count = KWindowSystem::numberOfDesktops();
+    const int count = KX11Extras::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
         if (info.isOnDesktop(n)) {
             attribute->setDesktop(n);
@@ -562,25 +564,20 @@ void KNote::slotKeepBelow()
 
 void KNote::updateKeepAboveBelow(bool save)
 {
-#if KDEPIM_HAVE_X11
-    NET::States state = KWindowInfo(winId(), NET::WMState).state();
-#else
-    NET::States state = {}; // neutral state, TODO
-#endif
     auto attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     if (m_keepAbove->isChecked()) {
         attribute->setKeepAbove(true);
         attribute->setKeepBelow(false);
-        KWindowSystem::setState(winId(), state | NET::KeepAbove);
+        windowHandle()->setFlag(Qt::WindowStaysOnTopHint, true);
     } else if (m_keepBelow->isChecked()) {
         attribute->setKeepAbove(false);
         attribute->setKeepBelow(true);
-        KWindowSystem::setState(winId(), state | NET::KeepBelow);
+        windowHandle()->setFlag(Qt::WindowStaysOnBottomHint, true);
     } else {
         attribute->setKeepAbove(false);
         attribute->setKeepBelow(false);
-        KWindowSystem::clearState(winId(), NET::KeepAbove);
-        KWindowSystem::clearState(winId(), NET::KeepBelow);
+        windowHandle()->setFlag(Qt::WindowStaysOnTopHint, false);
+        windowHandle()->setFlag(Qt::WindowStaysOnBottomHint, false);
     }
     if (!mBlockSave && save) {
         saveNoteContent();
@@ -618,9 +615,9 @@ void KNote::slotUpdateDesktopActions()
     auto separator = new QAction(m_toDesktop);
     separator->setSeparator(true);
     m_toDesktop->addAction(separator);
-    const int count = KWindowSystem::numberOfDesktops();
+    const int count = KX11Extras::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
-        QAction *desktopAct = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KWindowSystem::desktopName(n)));
+        QAction *desktopAct = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KX11Extras::desktopName(n)));
         desktopAct->setData(n);
         if (info.isOnDesktop(n)) {
             desktopAct->setChecked(true);
@@ -708,7 +705,11 @@ void KNote::createActions()
 #if KDEPIM_HAVE_X11
     m_toDesktop = new KSelectAction(i18n("To Desktop"), this);
     actionCollection()->addAction(QStringLiteral("to_desktop"), m_toDesktop);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(m_toDesktop, qOverload<QAction *>(&KSelectAction::triggered), this, &KNote::slotPopupActionToDesktop);
+#else
+    connect(m_toDesktop, &KSelectAction::actionTriggered, this, &KNote::slotPopupActionToDesktop);
+#endif
     connect(m_toDesktop->menu(), &QMenu::aboutToShow, this, &KNote::slotUpdateDesktopActions);
     // initially populate it, otherwise stays disabled
     slotUpdateDesktopActions();
@@ -868,7 +869,7 @@ void KNote::prepare()
 
 #if KDEPIM_HAVE_X11
     if ((desktop < 0 && desktop != NETWinInfo::OnAllDesktops) || !mDisplayAttribute->rememberDesktop()) {
-        desktop = KWindowSystem::currentDesktop();
+        desktop = KX11Extras::currentDesktop();
     }
 #endif
 
@@ -896,13 +897,6 @@ void KNote::prepare()
     }
 
     updateKeepAboveBelow();
-    // HACK: update the icon color - again after showing the note, to make kicker
-    // aware of the new colors
-    KIconEffect effect;
-    const QColor col = mDisplayAttribute->backgroundColor();
-    const QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)), KIconEffect::Colorize, 1, col, false);
-    const QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)), KIconEffect::Colorize, 1, col, false);
-    KWindowSystem::setIcons(winId(), icon, miniIcon);
 
     // set up the look&feel of the note
     setFrameStyle(Panel | Raised);
@@ -924,9 +918,9 @@ void KNote::toDesktop(int desktop)
 
 #if KDEPIM_HAVE_X11
     if (desktop == NETWinInfo::OnAllDesktops) {
-        KWindowSystem::setOnAllDesktops(winId(), true);
+        KX11Extras::setOnAllDesktops(winId(), true);
     } else {
-        KWindowSystem::setOnDesktop(winId(), desktop);
+        KX11Extras::setOnDesktop(winId(), desktop);
     }
 #endif
 }
@@ -974,11 +968,6 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
     // set the text color
     m_editor->setTextColor(fg);
 
-    // update the icon color
-    KIconEffect effect;
-    QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)), KIconEffect::Colorize, 1, bg, false);
-    QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)), KIconEffect::Colorize, 1, bg, false);
-    KWindowSystem::setIcons(winId(), icon, miniIcon);
     // update the color of the title
     updateFocus();
     Q_EMIT sigColorChanged();
@@ -1140,14 +1129,22 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
         }
 
         if (ev->type() == QEvent::MouseMove && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
+#else
+            QPoint newPos = e->globalPosition().toPoint() - mOrigPos - QPoint(1, 1);
+#endif
             move(newPos);
             return true;
         }
 
         if (ev->type() == QEvent::MouseButtonRelease
             && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
+#else
+            QPoint newPos = e->globalPosition().toPoint() - mOrigPos - QPoint(1, 1);
+#endif
             move(newPos);
             return false;
         }
